Learn R Programming

ggbeeswarm (version 0.5.0)

geom_beeswarm: Points, jittered to reduce overplotting using the beeswarm package

Description

The beeswarm geom is a convenient means to offset points within categories to reduce overplotting. Uses the beeswarm package

Usage

geom_beeswarm(mapping = NULL, data = NULL, priority = c("ascending", "descending", "density", "random", "none"), cex = 2, groupOnX = NULL, dodge.width = 0, stat = "identity", position = "quasirandom", na.rm = FALSE, show.legend = NA, inherit.aes = TRUE, ...)

Arguments

mapping
Set of aesthetic mappings created by aes or aes_. If specified and inherit.aes = TRUE (the default), is combined with the default mapping at the top level of the plot. You only need to supply mapping if there isn't a mapping defined for the plot.
data
A data frame. If specified, overrides the default data frame defined at the top level of the plot.
priority
Method used to perform point layout (see swarmx)
cex
Scaling for adjusting point spacing (see swarmx)
groupOnX
should jitter be added to the x axis if TRUE or y axis if FALSE (the default NULL causes the function to guess which axis is the categorical one based on the number of unique entries in each)
dodge.width
Amount by which points from different aesthetic groups will be dodged. This requires that one of the aesthetics is a factor.
stat
The statistical transformation to use on the data for this layer, as a string.
position
Position adjustment, either as a string, or the result of a call to a position adjustment function.
na.rm
If FALSE (the default), removes missing values with a warning. If TRUE silently removes missing values.
show.legend
logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.
inherit.aes
If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. borders.
...
other arguments passed on to layer. There are three types of arguments you can use here:

  • Aesthetics: to set an aesthetic to a fixed value, like color = "red" or size = 3.
  • Other arguments to the layer, for example you override the default stat associated with the layer.
  • Other arguments passed on to the stat.

Aesthetics

geom_point understands the following aesthetics (required aesthetics are in bold):
  • x
  • y
  • alpha
  • colour
  • fill
  • shape
  • size
  • stroke

See Also

geom_quasirandom an alternative method, swarmx how spacing is determined, geom_point for regular, unjittered points, geom_jitter for jittered points, geom_boxplot for another way of looking at the conditional distribution of a variable

Examples

Run this code

  ggplot2::qplot(class, hwy, data = ggplot2::mpg, geom='beeswarm')
  # Generate fake data
  distro <- data.frame(
    'variable'=rep(c('runif','rnorm'),each=100),
    'value'=c(runif(100, min=-3, max=3), rnorm(100))
  )
  ggplot2::qplot(variable, value, data = distro, geom='beeswarm')
  ggplot2::qplot(variable, value, data = distro) +
    geom_beeswarm(priority='density',cex=2.5)

Run the code above in your browser using DataLab